pandas.Grouper
==============

.. currentmodule:: pandas

.. autoclass:: Grouper

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      




   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      Grouper.ax
      Grouper.groups


